@@ -1,7 +1,7 @@
 package Guacamole::Deparse;
 our $AUTHORITY = 'cpan:XSAWYERX';
 # ABSTRACT: A Gaucamole-based Deparser
-$Guacamole::Deparse::VERSION = '0.002';
+$Guacamole::Deparse::VERSION = '0.003';
 use strict;
 use warnings;
 use parent 'Exporter';
@@ -36,7 +36,7 @@ sub deparse ($string) {
             # Take lexeme as a string element
             if (
                 is_hashref( $valueref->$* )
-             && $valueref->$*->{'type'} eq ':bare'
+             && $valueref->$*->{'type'} eq 'lexeme'
             ) {
                 push @elements, $valueref->$*->{'value'};
             }
@@ -60,7 +60,7 @@ sub fold_string ($valueref) {
 
     $valueref->$*->{'children'} = [
         {
-            'type'  => ':bare',
+            'type'  => 'lexeme',
             'value' => $value,
         }
     ];
@@ -80,7 +80,7 @@ Guacamole::Deparse - A Gaucamole-based Deparser
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
